@@ -1,10 +1,10 @@
-from .api_key import APIKeyQuery, APIKeyHeader, APIKeyCookie
+from .api_key import APIKeyCookie, APIKeyHeader, APIKeyQuery
 from .http import (
+    HTTPAuthorizationCredentials,
     HTTPBasic,
+    HTTPBasicCredentials,
     HTTPBearer,
     HTTPDigest,
-    HTTPBasicCredentials,
-    HTTPAuthorizationCredentials,
 )
-from .oauth2 import OAuth2PasswordRequestForm, OAuth2, OAuth2PasswordBearer
+from .oauth2 import OAuth2, OAuth2PasswordBearer, OAuth2PasswordRequestForm
 from .open_id_connect_url import OpenIdConnect
